pycocoa.nstypes.NSExceptionError

Package pycocoa :: Module nstypes :: Class NSExceptionError |
[frames] | no frames]

# Class NSExceptionError

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
            exceptions.StandardError --+
                                       |
                 exceptions.RuntimeError --+
                                           |
                                          NSExceptionError

Python Error wrapping an `ObjC/NSException`.

Used to wrap uncaught `ObjC/NSException`s, see setUncaughtExceptionHandler.

Instance Methods
__init__(self, nsExc) New NSExceptionError wrapper. |
Inherited from `exceptions.RuntimeError`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Class Variables
| NS = `None` hash(x)

Properties
| datetime Get the time stamp as "YYYY-MM-DD HH:MM:SS.MIL" (`str`).
| name Get the name of the exception (`str`).
| info Get additional info about the exception (Adict) or `None`.
| reason Get the reason for the exception (`str`) or `None`.
| callstack Get the callstack of this exception (`iter`), most recent last.
| timestamp Get the time stamp of this exception (`float`).
| versionstr Get the PyCocoa, Python, etc.
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details

### __init__(self, nsExc) (Constructor) |
New NSExceptionError wrapper. Parameters: `nsExc` - The `ObjC/NSException` instance to wrap. Overrides: object.__init__

Property Details

### datetime Get the time stamp as "YYYY-MM-DD HH:MM:SS.MIL" (`str`). Get Method: datetime(self) - Get the time stamp as "YYYY-MM-DD HH:MM:SS.MIL" (`str`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### name Get the name of the exception (`str`). Get Method: name(self) - Get the name of the exception (`str`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always. See Also: NSExceptionName.

### info Get additional info about the exception (Adict) or `None`. Get Method: info(self) - Get additional info about the exception (Adict) or `None`. Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### reason Get the reason for the exception (`str`) or `None`. Get Method: reason(self) - Get the reason for the exception (`str`) or `None`. Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### callstack Get the callstack of this exception (`iter`), most recent last. Get Method: callstack(self) - Get the callstack of this exception (`iter`), most recent last. Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### timestamp Get the time stamp of this exception (`float`). Get Method: timestamp(self) - Get the time stamp of this exception (`float`). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### versionstr Get the PyCocoa, Python, etc. versions (`str`). Get Method: versionstr(self) - Get the PyCocoa, Python, etc. Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.